import { OnChanges, TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * TabDirective ([unoTab]), is a structural Directive, to be used by <uno-tabs /> library component.
 * It's specifically tailored to create and destroy DOM elements, changing the HTML structure
 * Will be the minimum unit of <uno-tabs /> component library
 *
 * @example
 *
    <ng-template unoTab unoTabId="tab1" heading="Tab 1">
        Tab 1
    </ng-template>
    <ng-template unoTab unoTabId="tab2" heading="Tab 2">
        Tab 2
    </ng-template>
    <ng-template unoTab unoTabId="tab3" heading="Tab 3">
    ...
 *
 */
export declare class TabDirective implements OnChanges {
    templateRef: TemplateRef<any>;
    /**
     * Specifies the id of the tab
     */
    unoTabId: string;
    /**
     * Specifies the title and sub-title and if its uppercase (default) or natural case
     */
    heading: string | TemplateRef<any>;
    headingSub: string;
    headingNaturalCase: boolean;
    /**
     * Specifies the if tab is disable or not
     */
    disableTab: boolean;
    /**
     * Allow to set custom bgColor/txtColor:
     */
    bgColorHeading: string;
    txtColorHeading: string;
    bgColorContent: string;
    txtColorContent: string;
    bgHeightContent: string;
    /**
     * ... into our component's "customStyle" object, to be HTML applied:
     */
    customHeadingStyle: {};
    customContentStyle: {};
    /**
     * This Tab component is currently active (mounted) @ embedded view linked to this TemplateRef:
     */
    isTabActive: boolean;
    constructor(templateRef: TemplateRef<any>);
    ngOnChanges(): void;
    set active(active: boolean);
    get active(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<TabDirective, [{ optional: true; }]>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<TabDirective, "[unoTab]", never, { "unoTabId": "unoTabId"; "heading": "heading"; "headingSub": "headingSub"; "headingNaturalCase": "headingNaturalCase"; "disableTab": "disableTab"; "bgColorHeading": "bgColorHeading"; "txtColorHeading": "txtColorHeading"; "bgColorContent": "bgColorContent"; "txtColorContent": "txtColorContent"; "bgHeightContent": "bgHeightContent"; }, {}, never>;
}
